#
# spec file for package ghc-warp-tls
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name warp-tls
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        3.4.12
Release:        1.4
Summary:        HTTP over TLS support for Warp via the TLS package
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-recv-devel
BuildRequires:  ghc-recv-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-streaming-commons-devel
BuildRequires:  ghc-streaming-commons-prof
BuildRequires:  ghc-tls-devel
BuildRequires:  ghc-tls-prof
BuildRequires:  ghc-tls-session-manager-devel
BuildRequires:  ghc-tls-session-manager-prof
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-wai-prof
BuildRequires:  ghc-warp-devel
BuildRequires:  ghc-warp-prof
ExcludeArch:    %{ix86}

%description
SSLv1 and SSLv2 are obsoleted by IETF. We should use TLS 1.2 (or TLS 1.1 or TLS
1.0 if necessary). HTTP/2 can be negotiated by ALPN. API docs and the README
are available at <http://www.stackage.org/package/warp-tls>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Nov 19 2024 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.4.12.
  [#]# 3.4.12
  * Rethrowing asynchronous exceptions
    [#1013](https://github.com/yesodweb/wai/pull/1013)
* Thu Nov  7 2024 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.4.11.
  [#]# 3.4.11
  * Removing `unliftio`.
  [#]# 3.4.10
  * Removed `data-default` dependency entirely. Does now require `>= tls-2.1.3`.
    [#1011](https://github.com/yesodweb/wai/pull/1011)
  [#]# 3.4.9
  * Using `timeout` for `handshake` to prevent thread leaks.
  [#]# 3.4.8
  * Substituted `data-default-class` for `data-default` [#1010](https://github.com/yesodweb/wai/pull/1010)
* Wed Sep 25 2024 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.4.7.
  [#]# 3.4.7
  * Expose `attachConn` to use post-handshake TLS connection.
    [#1007](https://github.com/yesodweb/wai/pull/1007)
* Tue Jun 25 2024 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.4.6.
  [#]# 3.4.6
  * Preparing for tls v2.1
* Fri Apr 19 2024 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.4.5.
  [#]# 3.4.5
  * Making mkConn of WarpTLS interruptible
    [#984](https://github.com/yesodweb/wai/pull/984)
* Sat Feb  3 2024 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.4.4.
  [#]# 3.4.4
  * Allow warp v3.4.
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.4.3.
  [#]# 3.4.3
  * Install shutdown handlers passed via `Settings` to `run...` functions
  [#]# 3.4.2
  * Requiring warp v3.3.29.
  [#]# 3.4.1
  * Supporting `tls` v1.8.0.
  [#]# 3.4.0
  * Major version up to deprecate v3.3.7 due to the incompatibility
    against cryptonite.
  [#]# 3.3.7
  * Using crypton instead of cryptonite.
    [#931](https://github.com/yesodweb/wai/pull/931)
* Mon Jul 24 2023 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.3.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Mar 23 2023 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.3.6.
  [#]# 3.3.6
  * Setting FD_CLOEXEC on the listening socket.
    [#923](https://github.com/yesodweb/wai/pull/923)
* Wed Feb  8 2023 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.3.5.
  [#]# 3.3.5
  * Switching the version of the "recv" package from 0.0.x to 0.1.x.
* Wed Sep 28 2022 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.3.4.
  [#]# 3.3.4
  * Integrated customizable `accept` hook from `Network.Wai.Handler.Warp.Settings` (cf. `setAccept`)
    [#912](https://github.com/yesodweb/wai/pull/912)
  * Adjusted `httpOverTls` because of the factoring out of `Network.Wai.Handler.Warp.Recv` to its own package `recv` in the `warp` package.
    [#899](https://github.com/yesodweb/wai/pull/899)
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update warp-tls to version 3.3.3.
  [#] ChangeLog
  [#]# 3.3.3
  * Creating a bigger buffer when the current one is too small to fit the Builder
    [#895](https://github.com/yesodweb/wai/pull/895)
  * Expose TLS.supportedHashSignatures via TLSSettings
    [#872](https://github.com/yesodweb/wai/pull/872)
* Wed Sep 29 2021 psimons@suse.com
- Update warp-tls to version 3.3.2.
  [#]# 3.3.2
  * Providing the Internal module.
    [#841](https://github.com/yesodweb/wai/issues/841)
* Thu May 27 2021 psimons@suse.com
- Update warp-tls to version 3.3.1.
  [#]# 3.3.1
  * Move exception handling over to `unliftio` for better async exception support [#845](https://github.com/yesodweb/wai/issues/845)
  * Cleanly close connection when client closes connection prematurely [#844](https://github.com/yesodweb/wai/issues/844)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri Jun 26 2020 psimons@suse.com
- Update warp-tls to version 3.3.0.
  [#]# 3.3.0
  * Breaking changes: certFile and keyFile are not exported anymore.
  * Allow TLS credentials to be retrieved from an IORef.
    [#806](https://github.com/yesodweb/wai/pull/806)
* Tue Jun  9 2020 psimons@suse.com
- Add warp-tls at version 3.2.12.
